@@ -20,7 +20,8 @@ import (
 	"github.com/blacktop/ipsw/pkg/info"
 )
 
-func scanDmg(ipswPath, dmgPath, dmgType string, handler func(string, *macho.File) error) error {
+// TODO: make this an array of handlers to perform multiple actions on each file
+func scanDmg(ipswPath, dmgPath, dmgType, pemDB string, handler func(string, string) error) error {
 	// check if filesystem DMG already exists (due to previous mount command)
 	if _, err := os.Stat(dmgPath); os.IsNotExist(err) {
 		dmgs, err := utils.Unzip(ipswPath, "", func(f *zip.File) bool {
@@ -38,7 +39,7 @@ func scanDmg(ipswPath, dmgPath, dmgType string, handler func(string, *macho.File
 	}
 	if filepath.Ext(dmgPath) == ".aea" {
 		var err error
-		dmgPath, err = aea.Decrypt(dmgPath, filepath.Dir(dmgPath), nil)
+		dmgPath, err = aea.Decrypt(dmgPath, filepath.Dir(dmgPath), nil, pemDB)
 		if err != nil {
 			return fmt.Errorf("failed to parse AEA encrypted DMG: %v", err)
 		}
@@ -62,13 +63,40 @@ func scanDmg(ipswPath, dmgPath, dmgType string, handler func(string, *macho.File
 	}
 
 	var files []string
+	// Use a map to keep track of visited directories to avoid infinite loops
+	visited := make(map[string]bool)
 	if err := filepath.Walk(mountPoint, func(path string, info os.FileInfo, err error) error {
 		if err != nil {
 			log.Errorf("failed to walk mount %s: %v", path, err)
 			return nil
 		}
-		if !info.IsDir() {
-			files = append(files, path)
+		if info.Mode()&os.ModeSymlink != 0 { // follow symlinks
+			// Resolve the symlink
+			if linkPath, err := filepath.EvalSymlinks(path); err == nil {
+				// Get the info of the target file/directory
+				info, err = os.Stat(linkPath)
+				if err != nil {
+					return err
+				}
+				// If it's a directory and not visited, follow it
+				if info.IsDir() && !visited[linkPath] {
+					visited[linkPath] = true
+					return filepath.Walk(linkPath, func(subPath string, subInfo os.FileInfo, subErr error) error {
+						if subErr != nil {
+							return subErr
+						}
+						files = append(files, strings.TrimPrefix(subPath, "/private"))
+						return nil
+					})
+				}
+			}
+		} else {
+			if !info.IsDir() {
+				if !visited[path] {
+					visited[path] = true
+					files = append(files, path)
+				}
+			}
 		}
 		return nil
 	}); err != nil {
@@ -77,28 +105,7 @@ func scanDmg(ipswPath, dmgPath, dmgType string, handler func(string, *macho.File
 
 	for _, file := range files {
 		if err := func() error {
-			if ok, _ := magic.IsMachO(file); ok {
-				var m *macho.File
-				// UNIVERSAL MACHO
-				if fat, err := macho.OpenFat(file); err == nil {
-					defer fat.Close()
-					m = fat.Arches[len(fat.Arches)-1].File
-				} else { // SINGLE MACHO
-					if errors.Is(err, macho.ErrNotFat) {
-						m, err = macho.Open(file)
-						if err != nil {
-							return nil
-						}
-						defer m.Close()
-					} else { // NOT a macho file
-						return nil
-					}
-				}
-				if err := handler(strings.TrimPrefix(file, mountPoint), m); err != nil {
-					return fmt.Errorf("failed to handle macho %s: %w", file, err)
-				}
-			}
-			return nil
+			return handler(mountPoint, file)
 		}(); err != nil {
 			return err
 		}
@@ -108,7 +115,32 @@ func scanDmg(ipswPath, dmgPath, dmgType string, handler func(string, *macho.File
 }
 
 // ForEachMachoInIPSW walks the IPSW and calls the handler for each macho file found
-func ForEachMachoInIPSW(ipswPath string, handler func(string, *macho.File) error) error {
+func ForEachMachoInIPSW(ipswPath, pemDbPath string, handler func(string, *macho.File) error) error {
+	scanMacho := func(mountPoint, machoPath string) error {
+		if ok, _ := magic.IsMachO(machoPath); ok {
+			var m *macho.File
+			// UNIVERSAL MACHO
+			if fat, err := macho.OpenFat(machoPath); err == nil {
+				defer fat.Close()
+				m = fat.Arches[len(fat.Arches)-1].File
+			} else { // SINGLE MACHO
+				if errors.Is(err, macho.ErrNotFat) {
+					m, err = macho.Open(machoPath)
+					if err != nil {
+						return nil
+					}
+					defer m.Close()
+				} else { // NOT a macho file
+					return nil
+				}
+			}
+			if err := handler(strings.TrimPrefix(machoPath, mountPoint), m); err != nil {
+				return fmt.Errorf("failed to handle macho %s: %w", machoPath, err)
+			}
+		}
+		return nil
+	}
+
 	i, err := info.Parse(ipswPath)
 	if err != nil {
 		return fmt.Errorf("failed to parse IPSW: %v", err)
@@ -116,25 +148,25 @@ func ForEachMachoInIPSW(ipswPath string, handler func(string, *macho.File) error
 
 	if fsOS, err := i.GetFileSystemOsDmg(); err == nil {
 		log.Info("Scanning filesystem")
-		if err := scanDmg(ipswPath, fsOS, "filesystem", handler); err != nil {
+		if err := scanDmg(ipswPath, fsOS, "filesystem", pemDbPath, scanMacho); err != nil {
 			return fmt.Errorf("failed to scan files in filesystem %s: %w", fsOS, err)
 		}
 	}
 	if systemOS, err := i.GetSystemOsDmg(); err == nil {
 		log.Info("Scanning SystemOS")
-		if err := scanDmg(ipswPath, systemOS, "SystemOS", handler); err != nil {
+		if err := scanDmg(ipswPath, systemOS, "SystemOS", pemDbPath, scanMacho); err != nil {
 			return fmt.Errorf("failed to scan files in SystemOS %s: %w", systemOS, err)
 		}
 	}
 	if appOS, err := i.GetAppOsDmg(); err == nil {
 		log.Info("Scanning AppOS")
-		if err := scanDmg(ipswPath, appOS, "AppOS", handler); err != nil {
+		if err := scanDmg(ipswPath, appOS, "AppOS", pemDbPath, scanMacho); err != nil {
 			return fmt.Errorf("failed to scan files in AppOS %s: %w", appOS, err)
 		}
 	}
 	if excOS, err := i.GetExclaveOSDmg(); err == nil {
 		log.Info("Scanning ExclaveOS")
-		if err := scanDmg(ipswPath, excOS, "ExclaveOS", handler); err != nil {
+		if err := scanDmg(ipswPath, excOS, "ExclaveOS", pemDbPath, scanMacho); err != nil {
 			return fmt.Errorf("failed to scan files in ExclaveOS %s: %w", excOS, err)
 		}
 	}
@@ -186,3 +218,72 @@ func ForEachIm4pInIPSW(ipswPath string, handler func(string, *macho.File) error)
 
 	return nil
 }
+
+func ForEachPlistInIPSW(ipswPath, directory, pemDB string, handler func(string, string) error) error {
+	i, err := info.Parse(ipswPath)
+	if err != nil {
+		return fmt.Errorf("failed to parse IPSW: %v", err)
+	}
+
+	scanPlist := func(mountPoint, plistPath string) error {
+		// filter to only scan a specific directory (if provided)
+		if directory != "" && !strings.Contains(plistPath, directory) {
+			return nil
+		}
+		if strings.HasSuffix(plistPath, ".plist") {
+			// settings := make(map[string]interface{})
+			data, err := os.ReadFile(plistPath)
+			if err != nil {
+				return fmt.Errorf("failed to read plist %s: %v", plistPath, err)
+			}
+			// TODO: add support for binary plists
+			// pdata, err := plist.MarshalIndent(data, plist.XMLFormat, "  ")
+			// if err != nil {
+			// 	return fmt.Errorf("failed to marshal plist %s: %v", plistPath, err)
+			// }
+			// if err := plist.NewDecoder(bytes.NewReader(data)).Decode(&settings); err != nil {
+			// 	return fmt.Errorf("failed to decode plist %s: %v", plistPath, err)
+			// }
+			// jdata, err := json.MarshalIndent(settings, "", "  ")
+			// if err != nil {
+			// 	return fmt.Errorf("failed to marshal plist %s: %v", plistPath, err)
+			// }
+			plistPath = strings.TrimPrefix(plistPath, mountPoint)
+			plistPath, err = filepath.Rel(directory, plistPath)
+			if err != nil {
+				return fmt.Errorf("failed to get relative path for %s: %v", plistPath, err)
+			}
+			if err := handler(strings.TrimPrefix(plistPath, mountPoint), string(data)); err != nil {
+				return fmt.Errorf("failed to handle plist %s: %v", plistPath, err)
+			}
+		}
+		return nil
+	}
+
+	if fsOS, err := i.GetFileSystemOsDmg(); err == nil {
+		log.Info("Scanning filesystem")
+		if err := scanDmg(ipswPath, fsOS, "filesystem", pemDB, scanPlist); err != nil {
+			return fmt.Errorf("failed to scan files in filesystem %s: %w", fsOS, err)
+		}
+	}
+	if systemOS, err := i.GetSystemOsDmg(); err == nil {
+		log.Info("Scanning SystemOS")
+		if err := scanDmg(ipswPath, systemOS, "SystemOS", pemDB, scanPlist); err != nil {
+			return fmt.Errorf("failed to scan files in SystemOS %s: %w", systemOS, err)
+		}
+	}
+	if appOS, err := i.GetAppOsDmg(); err == nil {
+		log.Info("Scanning AppOS")
+		if err := scanDmg(ipswPath, appOS, "AppOS", pemDB, scanPlist); err != nil {
+			return fmt.Errorf("failed to scan files in AppOS %s: %w", appOS, err)
+		}
+	}
+	if excOS, err := i.GetExclaveOSDmg(); err == nil {
+		log.Info("Scanning ExclaveOS")
+		if err := scanDmg(ipswPath, excOS, "ExclaveOS", pemDB, scanPlist); err != nil {
+			return fmt.Errorf("failed to scan files in ExclaveOS %s: %w", excOS, err)
+		}
+	}
+
+	return nil
+}
